use web_sys::HtmlInputElement;
use yew::prelude::*;

#[derive(PartialEq, Debug, Default)]
pub enum AnteilsTyp {
    #[default]
    Anmeldungen,
    Gebote,
}

#[derive(PartialEq, Debug, Default)]
pub struct PersonenFilter {
    pub stammmitglied_alter_vp: bool,
    pub stammmitglied_neuer_vp: bool,
    pub neumitglied: bool,
}

#[derive(Properties, PartialEq, Debug, Default)]
pub struct ZuordnungsFilter {
    #[prop_or_default]
    pub jahr: Option<u32>,
    #[prop_or_default]
    pub ernte_anteile: AnteilsTyp,
    #[prop_or_default]
    pub personen: PersonenFilter,
    pub callback_jahr: Callback<Option<u32>>,
}

pub enum FilterMessages {}

pub struct Filter {
    pub jahr_node: NodeRef,
}

impl Component for Filter {
    type Message = FilterMessages;

    type Properties = ZuordnungsFilter;

    fn create(_ctx: &Context<Self>) -> Self {
        Self {
            jahr_node: NodeRef::default(),
        }
    }

    fn view(&self, ctx: &Context<Self>) -> Html {
        let jahre: Html = (2020..2035)
            .into_iter()
            .map(|x| {
                html! {<option value={x.to_string()} key={x}>
                  {x}
                </option>}
            })
            .collect();
        let on_change_year = {
            let node = self.jahr_node.clone();
            ctx.props().callback_jahr.reform(move |_| {
                let jahr = node.cast::<HtmlInputElement>()?;
                let jahr = jahr.value().parse().ok()?;
                Some(jahr)
            })
        };

        html! {
          <>
        <div class="container-fluid border border-light bg-light bg-gradient">
          <form action="" method="post">
            <div class="row">
              <div class="col-sm-4 d-flex justify-content-end">
                <label for="filterjahr">
                  <b>{"Zuordnung für Saison"}</b>
                </label>
              </div>
              <div class="col-sm-4">
                <select class="form-select" name="filterjahr" id="filterjahr" ref={&self.jahr_node} onchange={on_change_year}>
                  <option value="None" selected=true >{"Nicht ausgewählt"}</option>
                  {jahre}
                </select>
              </div>
            </div>
            <div class="row">
              <div class="col-sm-4 d-flex justify-content-end">
                <b> {"Zeige Ernteanteile"} </b>
              </div>
              <div class="col-sm-8">
                {radio("radio_anteile_anmeldung".into(), "auf Basis der Anmeldungen".into() )}
                {radio("radio_anteile_gebote".into(), "auf Basis der Gebote".into() )}
              </div>
            </div>
            <div class="row">
              <div class="col-sm-4 d-flex justify-content-end">
                <b> {"Zeige Personen"} </b>
              </div>
              <div class="col-sm-8">
                {check("check_bestandsmitglied_selberVP".to_string(), "Stammmitglieder, unveränderter VP-Erstwunsch".to_string())}
                {check("check_bestandsmitglied_neuerVP".to_string(), "Stammmitglieder, neuer VP-Erstwunsch".to_string())}
                {check("check_neueinsteiger".to_string(), "Neueinsteiger".to_string())}
              </div>
            </div>
          </form>
        </div>
        </>}
    }
}

fn radio(id: AttrValue, text: AttrValue) -> Html {
    html! {
      <div class="form-check">
        <input class="form-check-input" type="radio" name={id.clone()} id={id.clone()} checked=false />
        <label class="form-check-label" for={id}>{text}</label>
      </div>
    }
}
fn check(id: String, text: String) -> Html {
    html! {
      <div class="form-check">
        <input class="form-check-input" type="checkbox" name={id.clone()} id={id.clone()} checked=false />
        <label class="form-check-label" for={id}>{text}</label>
      </div>
    }
}
