use std::collections::HashMap;

use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, Default, Debug)]
pub struct Daten {
    pub vps: Vec<i32>,
    pub anfragen: Vec<GemüseAnfrage>,
    pub wuensche: Vec<VpWunsch>,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq)]
pub struct GemüseAnfrage {
    pub id: u32,
    pub anteile: u32,
    pub user: Benutzer,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq, Copy)]
pub struct VpWunsch {
    pub id: i32,
    pub anfrage_id: i32,
    pub user_id: i32,
    pub verteilpunkt_id: i32,
    pub prioritaet: i32,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Eq)]
pub struct Wünsche {
    pub wünsche: HashMap<i32, VpWunsch>,
    pub prioritäten: Vec<i32>,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq)]
pub struct Verteilpunkt {
    pub id: i32,
    pub name: String,
    pub kapazitaet: u32,
    pub anzahl_mitglieder: u32,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq)]
pub struct Benutzer {
    pub vorname: String,
    pub nachname: String,
    pub mitgliedsnummer: i32,
    pub gemüseanfragen: Vec<i32>,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq)]
pub struct VpZuordnung {
    pub mitgliedschaft_id: i32,
    pub user_mitgliedsnummer: i32,
    pub verteilpunkt_id: i32,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Eq)]
pub struct JahresVpZuordnung {
    pub jahr: i32,
    pub zuordnungen: HashMap<i32, VpZuordnung>,
}

#[derive(Serialize, Deserialize, Default, Debug, Clone, PartialEq, Hash, Eq)]
pub struct GeplanteVpZuordnung {
    pub mitgliedschaft_id: i32,
    pub user_mitgliedsnummer: i32,
    pub verteilpunkt_id: i32,
}
